Addr

Struct Addr 

pub struct Addr {
    pub ip: IpAddr,
    pub prefix: u8,
    pub scope: AddrScope,
    pub dynamic: bool,
    pub temporary: bool,
    pub deprecated: bool,
    pub mngtmpaddr: bool,
    pub noprefixroute: bool,
    pub valid_lft: Lifetime,
    pub preferred_lft: Lifetime,
    pub label: Option<String>,
}
A single address bound to a link.

Fields

ip: IpAddr

The IP address.

prefix: u8

Prefix length (CIDR).

scope: AddrScopedynamic: bool

Address was assigned dynamically (DHCP or SLAAC).

temporary: bool

RFC 4941 privacy extension address (IPv6).

deprecated: bool

preferred_lft == 0. New outgoing connections avoid these.

mngtmpaddr: bool

SLAAC “manage temporary addresses” — the stable base from which privacy addresses are derived.

noprefixroute: bool

IFA_F_NOPREFIXROUTE: a connected prefix route was not installed.

valid_lft: Lifetime

How long the address is valid. Forever for static addresses.

preferred_lft: Lifetime

How long the address is preferred for new outgoing connections.

label: Option<String>

Optional label string (from ip addr).