pub struct Flow {
pub proto: L4Proto,
pub local: SocketAddr,
pub remote: SocketAddr,
pub state: TcpState,
pub process: ProcessInfo,
pub bytes_in: u64,
pub bytes_out: u64,
pub rtt_us: Option<u32>,
}Expand description
An established or in-flight connection to/from this host.
Fields
proto: L4Protolocal: SocketAddrLocal socket address.
remote: SocketAddrRemote peer socket address.
state: TcpStateprocess: ProcessInfobytes_in: u64Bytes received on this flow.
bytes_out: u64Bytes sent on this flow.
rtt_us: Option<u32>Smoothed round-trip time in microseconds, when the kernel has one (TCP only, and only once the connection has carried data).