Actions

Trait Actions 

pub trait Actions: Send + Sync {
    // Required methods
    fn prefer(&self, id: &ConnectionId) -> Result<()>;
    fn forget(&self, id: &ConnectionId) -> Result<()>;
    fn reconnect(&self, id: &ConnectionId) -> Result<()>;
    fn set_autoconnect(&self, id: &ConnectionId, on: bool) -> Result<()>;
}
Write operations on connections (requires NetworkManager or similar).

Required Methods

fn prefer(&self, id: &ConnectionId) -> Result<()>

Activate the connection identified by id.

fn forget(&self, id: &ConnectionId) -> Result<()>

Delete the connection profile identified by id.

fn reconnect(&self, id: &ConnectionId) -> Result<()>

Deactivate and then reactivate the connection identified by id.

fn set_autoconnect(&self, id: &ConnectionId, on: bool) -> Result<()>

Enable or disable autoconnect for the connection identified by id.

Implementors