pub trait Actions: Send + Sync {
// Required methods
fn prefer(&self, id: &ConnectionId) -> Result<()>;
fn forget(&self, id: &ConnectionId) -> Result<()>;
fn reconnect(&self, id: &ConnectionId) -> Result<()>;
fn set_autoconnect(&self, id: &ConnectionId, on: bool) -> Result<()>;
}Expand description
Write operations on connections (requires NetworkManager or similar).
Required Methods
Sourcefn prefer(&self, id: &ConnectionId) -> Result<()>
fn prefer(&self, id: &ConnectionId) -> Result<()>
Activate the connection identified by id.
Sourcefn forget(&self, id: &ConnectionId) -> Result<()>
fn forget(&self, id: &ConnectionId) -> Result<()>
Delete the connection profile identified by id.
Sourcefn reconnect(&self, id: &ConnectionId) -> Result<()>
fn reconnect(&self, id: &ConnectionId) -> Result<()>
Deactivate and then reactivate the connection identified by id.
Sourcefn set_autoconnect(&self, id: &ConnectionId, on: bool) -> Result<()>
fn set_autoconnect(&self, id: &ConnectionId, on: bool) -> Result<()>
Enable or disable autoconnect for the connection identified by id.